*****************
Utility functions
*****************

This module contains simple utility functions that are used in several of MARXS submodules.

.. automodapi:: marxs.math

.. automodapi:: marxs.math.geometry
		
.. automodapi:: marxs.math.pluecker

.. automodapi:: marxs.math.polarization

.. automodapi:: marxs.math.random

.. automodapi:: marxs.math.rotations

.. automodapi:: marxs.math.utils

.. automodapi:: marxs.utils

